@@ -249,3 +249,23 @@ class InvokerTest(TestCase):
 
         self.assertEqual(handler.call_count, 1)
         handler.assert_has_calls([call(payload, command)])
+
+    def testDispatchRequestReturnsResponseWithCode400WhenRequestDoesNotHaveCommand(self):
+            with self.app.test_request_context(
+                content_type="application/json",
+                data=dumps({"payload": {}}),
+                method="POST",
+            ):
+                response = Invoker().dispatch_request()
+
+            self.assertEqual(response[1], 400)
+
+    def testDispatchRequestReturnsResponseWithCode400WhenRequestDoesNotHavePayload(self):
+            with self.app.test_request_context(
+                content_type="application/json",
+                data=dumps({"command": "foo.bar"}),
+                method="POST",
+            ):
+                response = Invoker().dispatch_request()
+
+            self.assertEqual(response[1], 400)
